import * as request from 'superagent'
import * as Debug from 'debug'

const log = Debug('middleware:session:requests')

export async function getSession(url: string, sid: string) {
  let response

  try {
    log(`Trying to get SID:${sid}`)
    response = await request.get(`${url}/api/session/${sid}`)
    log(`Successfully got SID:${sid}`)
  } catch (err) {
    response = { body: null, status: err.status || 500 }
  }

  if (response.status === 404) {
    log(`Cound't find SID:${sid}`)
    return createSession(url)
  }

  return response.body
}

export async function createSession(url: string) {
  let response

  try {
    log('Creating a new SID')
    response = await request.post(`${url}/api/session`)
    log(`Successfully created new SID: ${response.body.id}`)
  } catch (err) {
    response = { body: null }
  }

  return response.body
}

export async function updateSession(url: string, sid: string, obj: any) {
  let response

  try {
    log(`Trying to update SID:${sid}`)
    response = await request.patch(`${url}/api/session/${sid}`).send(obj)
    log(`Successfully updated SID:${sid}`)
  } catch (err) {
    response = { body: null }
  }

  return response.body
}
